@@ -1,16 +1,15 @@
-package HTML::FormWidgets::ScrollingList;
+# @(#)$Id: ScrollingList.pm 224 2010-02-12 18:44:46Z pjf $
 
-# @(#)$Id: ScrollingList.pm 184 2009-06-13 22:25:28Z pjf $
+package HTML::FormWidgets::ScrollingList;
 
 use strict;
 use warnings;
+use version; our $VERSION = qv( sprintf '0.6.%d', q$Rev: 224 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
-use version; our $VERSION = qv( sprintf '0.5.%d', q$Rev: 184 $ =~ /\d+/gmx );
-
 __PACKAGE__->mk_accessors( qw(height labels values) );
 
-sub _init {
+sub init {
    my ($self, $args) = @_;
 
    $self->height( 10 );
@@ -19,9 +18,10 @@ sub _init {
    return;
 }
 
-sub _render {
+sub render_field {
    my ($self, $args) = @_;
 
+   $args->{class }  .= q( ifield);
    $args->{labels}   = $self->labels   if ($self->labels);
    $args->{onchange} = $self->onchange if ($self->onchange);
    $args->{size}     = $self->height;
