@@ -1,26 +1,26 @@
-package HTML::FormWidgets::Textfield;
+# @(#)$Id: Textfield.pm 279 2010-08-29 00:17:46Z pjf $
 
-# @(#)$Id: Textfield.pm 184 2009-06-13 22:25:28Z pjf $
+package HTML::FormWidgets::Textfield;
 
 use strict;
 use warnings;
+use version; our $VERSION = qv( sprintf '0.6.%d', q$Rev: 279 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
-use version; our $VERSION = qv( sprintf '0.5.%d', q$Rev: 184 $ =~ /\d+/gmx );
-
 __PACKAGE__->mk_accessors( qw(width) );
 
-sub _init {
+sub init {
    my ($self, $args) = @_;
 
    $self->width( 40 );
    return;
 }
 
-sub _render {
+sub render_field {
    my ($self, $args) = @_;
 
-   $args->{size} = $self->width;
+   $args->{class} .= q( ).($self->class || q(ifield));
+   $args->{size }  = $self->width;
 
    return $self->hacc->textfield( $args );
 }
